// This file is autogenerated by CMake. Do not edit.

#include <QtCore/qtsymbolmacros.h>
#include <QtQml/qqmlextensionplugin.h>



QT_DECLARE_EXTERN_RESOURCE(qmake_org_deepin_launchpad_models)


QT_DECLARE_EXTERN_SYMBOL_VOID(qml_register_types_org_deepin_launchpad_models)

class org_deepin_launchpad_modelsPlugin : public QQmlEngineExtensionPlugin
{
    Q_OBJECT
    Q_PLUGIN_METADATA(IID QQmlEngineExtensionInterface_iid)

public:
    org_deepin_launchpad_modelsPlugin(QObject *parent = nullptr) : QQmlEngineExtensionPlugin(parent)
    {

QT_KEEP_SYMBOL(qml_register_types_org_deepin_launchpad_models)

QT_KEEP_RESOURCE(qmake_org_deepin_launchpad_models)
    }
};



#include "launcher-models_org_deepin_launchpad_modelsPlugin.moc"
